@@ -1,14 +1,15 @@
-EGI <- function(T, model, method=NULL, method.param=NULL, fun, 
-				iter, lower, upper, new.noise.var=0,optimcontrol=NULL, kmcontrol=NULL,integcontrol=NULL,...) {
+EGI <- function(T, model, method=NULL, method.param=NULL, 
+            fun, iter, lower, upper, new.noise.var=0,
+            optimcontrol=NULL, kmcontrol=NULL,integcontrol=NULL,...) {
 
-	n <- nrow(model@X)
-	d <- model@d
+	n <- nrow(model@X); d <- model@d
 	
 	if (is.null(kmcontrol$penalty)) kmcontrol$penalty <- model@penalty
 	if (length(model@penalty==0)) kmcontrol$penalty <- NULL 
 	if (is.null(kmcontrol$optim.method)) kmcontrol$optim.method <- model@optim.method 
 	if (is.null(kmcontrol$parinit)) kmcontrol$parinit <- model@parinit
 	if (is.null(kmcontrol$control)) kmcontrol$control <- model@control
+	if (is.null(kmcontrol$CovReEstimate)) kmcontrol$CovReEstimate <- model@param.estim
 	if (is.null(method)) method <- "ranjan"
 	
 	for (i in 1:iter) {
@@ -34,14 +35,13 @@ EGI <- function(T, model, method=NULL, method.param=NULL, fun,
 			oEGI <- max_infill_criterion(lower=lower, upper=upper,T=T, method=method, 
 								method.param=method.param,model=model,optimcontrol=optimcontrol)
 		}
+    
 		print("New point"); print(oEGI$par)
-		
 		X.new <- oEGI$par; y.new <- fun(oEGI$par,...)
-		X.new <- as.numeric(X.new)
-		X.new <- matrix(X.new,nrow=1,ncol=d)
+		X.new <- as.numeric(X.new); X.new <- matrix(X.new,nrow=1,ncol=d)
+		
+		model <- update_km(model=model,NewX=X.new,NewY=y.new,CovReEstimate=kmcontrol$CovReEstimate,new.noise.var=new.noise.var,kmcontrol=kmcontrol) #call to update_km
 		
-		model <- update_km(model=model,NewX=X.new,NewY=y.new,CovReEstimate=TRUE,new.noise.var=new.noise.var,kmcontrol=kmcontrol) #call to update_km
-		#only for the speed tests !	#model <- update_km(model=model,NewX=X.new,NewY=y.new,CovReEstimate=FALSE,new.noise.var=new.noise.var,kmcontrol=kmcontrol)
 	}
 	return(list(
 				par=model@X[(n+1):(n+iter),, drop=FALSE], 
